==> date_ical-4.0.0.tar.gz: date_ical/src/DateICal.php <==
<?php

declare(strict_types=1);

namespace Drupal\date_ical;

use Kigkonsult\Icalcreator\Vcalendar;

/**
 * Date iCal service.
 */
class DateICal implements DateICalInterface {

  /**
   * Feed iCal.
   *
   * @param array $events
   *   Event items.
   * @param array $header
   *   iCal header Example.
   */
  public function feed(array $events, array $header = []) {
    $baseUrl = \Drupal::request()->getHost();
    $timezone = date_default_timezone_get();
    $dateTimeZone = new \DateTimezone($timezone);
    $vcalendar = Vcalendar::factory([Vcalendar::UNIQUE_ID => $baseUrl])
      ->setMethod(Vcalendar::PUBLISH);
    foreach ($header as $wr => $value) {
      if (!empty($value) && defined("Vcalendar::X_WR_$wr")) {
        $const = constant("Vcalendar::X_WR_$wr");
        $vcalendar->setXprop($const, $value);
      }
    }
    foreach ($events as $row_index => $field) {
      $start = $field['date_field'];
      $end = NULL;
      if (is_array($start)) {
        $start = $field['date_field']['value'];
        $end = $field['date_field']['end_value'] ?? NULL;
        if ($end == $start) {
          $end = NULL;
        }
      }
      $event = $vcalendar->newVevent()
        ->setTransp(Vcalendar::OPAQUE)
        ->setClass(Vcalendar::P_BLIC)
        ->setSequence($row_index + 1)
        ->setDtstart(new \DateTime($start, $dateTimeZone));
      if (!empty($end)) {
        $event->setDtend(new \DateTime($end, $dateTimeZone));
      }

      // Render description.
      if (!empty($field['description_field'])) {
        $event->setDescription($field['description_field']);
      }
      // Render summary.
      if (!empty($field['summary_field'])) {
        $event->setSummary($field['summary_field']);
      }
      // Render description.
      if (!empty($field['description_field'])) {
        $event->setDescription($field['description_field']);
      }
      // Render geolocation.
      if (!empty($field['geo_field'])) {
        $event->setGeo($field['geo_field']['lat'], $field['geo_field']['lon']);
      }
      // Render location.
      if (!empty($field['location_field'])) {
        $event->setLocation($field['location_field']);
      }
      // Render organizer. Get only one organizer.
      if (!empty($field['organizer_field'])) {
        $organizer = current($field['organizer_field']);
        if (is_string($organizer)) {
          $event->setOrganizer($organizer);
        }
        elseif (is_array($organizer)) {
          $event->setOrganizer($organizer['mail'], [Vcalendar::CN => $organizer['name']]);
        }
      }
      // Render categories.
      if (!empty($field['categories_field'])) {
        $event->setCategories($field['categories_field']);
      }
      // Render status.
      $vEventStatus = ['CONFIRMED', 'CANCELLED', 'TENTATIVE'];
      if (!empty($field['status_field']) && in_array($field['status_field'], $vEventStatus)) {
        $event->setStatus($field['status_field']);
      }
      // Render URL.
      if (!empty($field['url_field'])) {
        $event->setUrl($field['url_field']);
      }
      // Render attendees.
      if (!empty($field['attendee_field'])) {
        foreach ($field['attendee_field'] as $attendee) {
          if (is_string($attendee)) {
            $event->setAttendee($attendee);
          }
          elseif (is_array($attendee)) {
            $event->setAttendee($attendee['mail'], [
              Vcalendar::ROLE => Vcalendar::REQ_PARTICIPANT,
              Vcalendar::PARTSTAT => Vcalendar::NEEDS_ACTION,
              Vcalendar::RSVP => Vcalendar::TRUE,
              Vcalendar::CN => $attendee['name'],
            ]);
          }
        }
        unset($field['attendee_field']);
      }
      // Render attachments.
      if (!empty($field['attach_field'])) {
        if (is_array($field['attach_field'])) {
          foreach ($field['attach_field'] as $attach) {
            $event->setAttach($attach);
          }
        }
      }
      // Render alarm.
      if (!empty($field['alarm_field'])) {
        if (is_numeric($field['alarm_field'])) {
          $field['alarm_field'] = 'PT' . $field['alarm_field'] . 'M';
        }
        $event->newValarm()
          ->setAction(Vcalendar::DISPLAY)
          ->setDescription($event->getDescription())
          ->setTrigger('-' . $field['alarm_field']);
      }
      // Render dtstamp.
      if (isset($field['exclude_dtstamp'])) {
        $event->setDtstamp($field['exclude_dtstamp']);
      }
      // Render created.
      if (isset($field['created'])) {
        $event->setCreated($field['created']);
      }
      // Render created.
      if (isset($field['last-modified'])) {
        $event->setLastmodified($field['last-modified']);
      }

    }
    $output = $vcalendar->vtimezonePopulate()->createCalendar();
    return $output;
  }

}

==> date_ical-4.0.1.tar.gz: date_ical/src/DateICal.php <==
<?php

declare(strict_types=1);

namespace Drupal\date_ical;

use Kigkonsult\Icalcreator\Vcalendar;

/**
 * Date iCal service.
 */
class DateICal implements DateICalInterface {

  /**
   * Feed iCal.
   *
   * @param array $events
   *   Event items.
   * @param array $header
   *   iCal header Example.
   */
  public function feed(array $events, array $header = []) {
    $baseUrl = \Drupal::request()->getHost();
    $timezone = date_default_timezone_get();
    $dateTimeZone = new \DateTimezone($timezone);
    $vcalendar = Vcalendar::factory([Vcalendar::UNIQUE_ID => $baseUrl])
      ->setMethod(Vcalendar::PUBLISH);
    foreach ($header as $wr => $value) {
      if (!empty($value)) {
        $vcalendar->setXprop("x-wr-$wr", $value);
      }
    }
    foreach ($events as $row_index => $field) {
      $start = $field['date_field'];
      $end = NULL;
      if (is_array($start)) {
        $start = $field['date_field']['value'];
        $end = $field['date_field']['end_value'] ?? NULL;
        if ($end == $start) {
          $end = NULL;
        }
      }
      $event = $vcalendar->newVevent()
        ->setTransp(Vcalendar::OPAQUE)
        ->setClass(Vcalendar::P_BLIC)
        ->setSequence($row_index + 1)
        ->setDtstart(new \DateTime($start, $dateTimeZone));
      if (!empty($end)) {
        $event->setDtend(new \DateTime($end, $dateTimeZone));
      }

      // Render description.
      if (!empty($field['description_field'])) {
        $event->setDescription((string) $field['description_field']);
      }
      // Render summary.
      if (!empty($field['summary_field'])) {
        $event->setSummary($field['summary_field']);
      }
      // Render description.
      if (!empty($field['description_field'])) {
        $event->setDescription($field['description_field']);
      }
      // Render geolocation.
      if (!empty($field['geo_field'])) {
        $event->setGeo($field['geo_field']['lat'], $field['geo_field']['lon']);
      }
      // Render location.
      if (!empty($field['location_field'])) {
        $event->setLocation($field['location_field']);
      }
      // Render organizer. Get only 1 organizer. It must be @mail or mail array.
      if (!empty($field['organizer_field'])) {
        $organizer = current($field['organizer_field']);
        if (is_string($organizer) && filter_var($organizer, FILTER_VALIDATE_EMAIL)) {
          $event->setOrganizer($organizer);
        }
        elseif (!empty($organizer['mail'])) {
          if (filter_var($organizer['mail'], FILTER_VALIDATE_EMAIL)) {
            $event->setOrganizer($organizer['mail'], [Vcalendar::CN => $organizer['name'] ?? '']);
          }
        }
      }
      // Render categories.
      if (!empty($field['categories_field'])) {
        $event->setCategories($field['categories_field']);
      }
      // Render status.
      $vEventStatus = ['CONFIRMED', 'CANCELLED', 'TENTATIVE'];
      if (!empty($field['status_field']) && in_array($field['status_field'], $vEventStatus)) {
        $event->setStatus($field['status_field']);
      }
      // Render URL.
      if (!empty($field['url_field'])) {
        $event->setUrl($field['url_field']);
      }
      // Render attendees. It must be @mail or mail array.
      if (!empty($field['attendee_field'])) {
        foreach ($field['attendee_field'] as $attendee) {
          if (is_string($attendee) && filter_var($attendee, FILTER_VALIDATE_EMAIL)) {
            $event->setAttendee($attendee);
          }
          elseif (!empty($attendee['mail']) && filter_var($attendee['mail'], FILTER_VALIDATE_EMAIL)) {
            $event->setAttendee($attendee['mail'], [
              Vcalendar::ROLE => Vcalendar::REQ_PARTICIPANT,
              Vcalendar::PARTSTAT => Vcalendar::NEEDS_ACTION,
              Vcalendar::RSVP => Vcalendar::TRUE,
              Vcalendar::CN => $attendee['name' ?? ''],
            ]);
          }
        }
        unset($field['attendee_field']);
      }
      // Render attachments.
      if (!empty($field['attach_field'])) {
        if (is_array($field['attach_field'])) {
          foreach ($field['attach_field'] as $attach) {
            $event->setAttach($attach);
          }
        }
      }
      // Render alarm.
      if (!empty($field['alarm_field'])) {
        if (is_numeric($field['alarm_field'])) {
          $field['alarm_field'] = 'PT' . $field['alarm_field'] . 'M';
        }
        $event->newValarm()
          ->setAction(Vcalendar::DISPLAY)
          ->setDescription($event->getDescription())
          ->setTrigger('-' . $field['alarm_field']);
      }
      // Render dtstamp.
      if (isset($field['exclude_dtstamp'])) {
        $event->setDtstamp($field['exclude_dtstamp']);
      }
      // Render created.
      if (isset($field['created'])) {
        $event->setCreated($field['created']);
      }
      // Render created.
      if (isset($field['last-modified'])) {
        $event->setLastmodified($field['last-modified']);
      }
      // Render uid.
      if (isset($field['uuid'])) {
        $event->setUid($field['uuid']);
      }
    }
    $output = $vcalendar->vtimezonePopulate()->createCalendar();
    return $output;
  }

}
